Module schema

Module schema 

Structs

SchemaCheck
This type is used to hold all information necessary to report back to the user about the mismatch from the schema to their current environment.
ValidatedAttribute

Enums

FinalizedSchema
Describes valid schemas with resolved references
ValidatedOptions

Type Aliases

EnvMap